@@ -6,16 +6,15 @@
 #include <type_traits>
 
 #include "ecole/data/parser.hpp"
-#include "ecole/dynamics/dynamics.hpp"
 #include "ecole/exception.hpp"
 #include "ecole/information/abstract.hpp"
 #include "ecole/random.hpp"
 #include "ecole/reward/abstract.hpp"
 #include "ecole/scip/model.hpp"
-#include "ecole/scip/type.hpp"
+#include "ecole/scip/seed.hpp"
 #include "ecole/traits.hpp"
 
-#include <iostream>
+#include <optional>
 
 template <typename T> struct is_optional : std::false_type {};
 template <typename T> struct is_optional<std::optional<T>> : std::true_type {};
@@ -54,7 +53,7 @@ public:
 	/**
 	 * Default construct everything and seed environment with random value.
 	 */
-	Environment() : the_random_engine(spawn_random_engine()) {}
+	Environment() : the_rng(spawn_random_generator()) {}
 
 	/**
 	 * Fully customize environment and seed environment with random value.
@@ -67,11 +66,11 @@ public:
 		std::map<std::string, scip::Param> scip_params = {},
 		Args&&... args) :
 		the_dynamics(std::forward<Args>(args)...),
-		the_observation_function(data::parse(std::move(observation_function))),
 		the_reward_function(data::parse(std::move(reward_function))),
+		the_observation_function(data::parse(std::move(observation_function))),
 		the_information_function(data::parse(std::move(information_function))),
 		the_scip_params(std::move(scip_params)),
-		the_random_engine(spawn_random_engine()) {}
+		the_rng(spawn_random_generator()) {}
 
 	/**
 	 * Set the random seed for the environment, hence making its internals deterministic.
@@ -84,7 +83,7 @@ public:
 	 * sequence of action taken are also unchanged), one has to seed the environment before
 	 * every call to reset.
 	 */
-	void seed(Seed new_seed) { random_engine().seed(new_seed); }
+	void seed(Seed new_seed) { rng().seed(new_seed); }
 
 	/**
 	 * Reset the environment to the initial state on the given problem instance.
@@ -109,25 +108,26 @@ public:
 			// Create clean new Model
 			model() = std::move(new_model);
 			model().set_params(scip_params());
-			dynamics().set_dynamics_random_state(model(), random_engine());
+			dynamics().set_dynamics_random_state(model(), rng());
 
 			// Reset data extraction function and bring model to initial state.
-			observation_function().before_reset(model());
 			reward_function().before_reset(model());
+			observation_function().before_reset(model());
 			information_function().before_reset(model());
-			auto const [done, action_set] = dynamics().reset_dynamics(model(), std::forward<Args>(args)...);
+
+			// Place the environment in its initial state
+			auto [done, action_set] = dynamics().reset_dynamics(model(), std::forward<Args>(args)...);
 			can_transition = !done;
 
-			auto observation = OptionalObservation{};
-			if (!done) {
-				observation = observation_function().extract(model(), done);
-			}
+			// Extract additional information to be returned by reset
+			auto [reward, observation, information] = extract_reward_observation_information(done);
+
 			return {
 				std::move(observation),
 				std::move(action_set),
-				reward_function().extract(model(), done),
+				std::move(reward),
 				done,
-				information_function().extract(model(), done),
+				std::move(information),
 			};
 		} catch (std::exception const&) {
 			can_transition = false;
@@ -167,22 +167,22 @@ public:
 	auto step(Action const& action, Args&&... args)
 		-> std::tuple<OptionalObservation, ActionSet, Reward, bool, InformationMap> {
 		if (!can_transition) {
-			throw Exception("Environment need to be reset.");
+			throw MarkovError{"Environment need to be reset."};
 		}
 		try {
-			auto const [done, action_set] = dynamics().step_dynamics(model(), action, std::forward<Args>(args)...);
+			// Transition the environment to the next state
+			auto [done, action_set] = dynamics().step_dynamics(model(), action, std::forward<Args>(args)...);
 			can_transition = !done;
 
-			auto observation = OptionalObservation{};
-			if (!done) {
-				observation = observation_function().extract(model(), done);
-			}
+			// Extract additional information to be returned by step
+			auto [reward, observation, information] = extract_reward_observation_information(done);
+
 			return {
 				std::move(observation),
 				std::move(action_set),
-				reward_function().extract(model(), done),
+				std::move(reward),
 				done,
-				information_function().extract(model(), done),
+				std::move(information),
 			};
 		} catch (std::exception const&) {
 			can_transition = false;
@@ -196,17 +196,27 @@ public:
 	auto& reward_function() { return the_reward_function; }
 	auto& information_function() { return the_information_function; }
 	auto& scip_params() { return the_scip_params; }
-	auto& random_engine() { return the_random_engine; }
+	auto& rng() { return the_rng; }
 
 private:
 	Dynamics the_dynamics;
 	scip::Model the_model;
-	ObservationFunction the_observation_function;
 	RewardFunction the_reward_function;
+	ObservationFunction the_observation_function;
 	InformationFunction the_information_function;
 	std::map<std::string, scip::Param> the_scip_params;
-	RandomEngine the_random_engine;
+	RandomGenerator the_rng;
 	bool can_transition = false;
+
+	// extract reward, observation and information (in that order)
+	auto extract_reward_observation_information(bool done) -> std::tuple<Reward, OptionalObservation, InformationMap> {
+		auto reward = reward_function().extract(model(), done);
+		// Don't extract observations in final states
+		auto observation = done ? OptionalObservation{} : observation_function().extract(model(), done);
+		auto information = information_function().extract(model(), done);
+
+		return {std::move(reward), std::move(observation), std::move(information)};
+	}
 };
 
 }  // namespace ecole::environment
