@@ -14,13 +14,13 @@ BranchingDynamics::BranchingDynamics(bool pseudo_candidates_) noexcept : pseudo_
 
 namespace {
 
-std::optional<xt::xtensor<std::size_t, 1>> action_set(scip::Model const& model, bool pseudo) {
+auto action_set(scip::Model const& model, bool pseudo) -> std::optional<xt::xtensor<std::size_t, 1>> {
 	if (model.stage() != SCIP_STAGE_SOLVING) {
 		return {};
 	}
 	auto const branch_cands = pseudo ? model.pseudo_branch_cands() : model.lp_branch_cands();
 	auto branch_cols = xt::xtensor<std::size_t, 1>::from_shape({branch_cands.size()});
-	auto const var_to_idx = [](auto const var) { return SCIPcolGetLPPos(SCIPvarGetCol(var)); };
+	auto const var_to_idx = [](auto const var) { return SCIPvarGetProbindex(var); };
 	std::transform(branch_cands.begin(), branch_cands.end(), branch_cols.begin(), var_to_idx);
 
 	assert(branch_cols.size() > 0);
@@ -29,7 +29,7 @@ std::optional<xt::xtensor<std::size_t, 1>> action_set(scip::Model const& model,
 
 }  // namespace
 
-auto BranchingDynamics::reset_dynamics(scip::Model& model) -> std::tuple<bool, ActionSet> {
+auto BranchingDynamics::reset_dynamics(scip::Model& model) const -> std::tuple<bool, ActionSet> {
 	model.solve_iter_start_branch();
 	if (model.solve_iter_is_done()) {
 		return {true, {}};
@@ -37,15 +37,23 @@ auto BranchingDynamics::reset_dynamics(scip::Model& model) -> std::tuple<bool, A
 	return {false, action_set(model, pseudo_candidates)};
 }
 
-auto BranchingDynamics::step_dynamics(scip::Model& model, std::size_t const& var_idx) -> std::tuple<bool, ActionSet> {
-	auto const lp_cols = model.lp_columns();
-	if (var_idx >= lp_cols.size()) {
-		throw std::invalid_argument{
-			fmt::format("Branching candidate index {} larger than the number of columns ({}).", var_idx, lp_cols.size())};
+auto BranchingDynamics::step_dynamics(scip::Model& model, Defaultable<std::size_t> maybe_var_idx) const
+	-> std::tuple<bool, ActionSet> {
+	if (std::holds_alternative<std::size_t>(maybe_var_idx)) {
+		auto const var_idx = std::get<std::size_t>(maybe_var_idx);
+		auto const vars = model.variables();
+		// Error handling
+		if (var_idx >= vars.size()) {
+			throw std::invalid_argument{
+				fmt::format("Branching candidate index {} larger than the number of variables ({}).", var_idx, vars.size())};
+		}
+		// Branching
+		scip::call(SCIPbranchVar, model.get_scip_ptr(), vars[var_idx], nullptr, nullptr, nullptr);
+		model.solve_iter_branch(SCIP_BRANCHED);
+	} else {
+		// Fallback to SCIP default branching
+		model.solve_iter_branch(SCIP_DIDNOTRUN);
 	}
-	auto* const var = SCIPcolGetVar(lp_cols[var_idx]);
-	scip::call(SCIPbranchVar, model.get_scip_ptr(), var, nullptr, nullptr, nullptr);
-	model.solve_iter_branch(SCIP_BRANCHED);
 
 	if (model.solve_iter_is_done()) {
 		return {true, {}};
